<?php
/**
* Lavinya Black functions and definitions
*
* Sets up the theme and provides some helper functions, which are used
* in the theme as custom template tags. Others are attached to action and
* filter hooks in WordPress to change core functionality.
*
* When using a child theme you can override certain functions (those wrapped
* in a function_exists() call) by defining them first in your child theme's
* functions.php file. The child theme's functions.php file is included before
* the parent theme's file, so the child theme functions would be used.
*
* @link https://developer.wordpress.org/themes/basics/theme-functions/
* @link https://developer.wordpress.org/themes/advanced-topics/child-themes/
*
* Functions that are not pluggable (not wrapped in function_exists()) are instead attached
* to a filter or action hook.
*
* For more information on hooks, actions, and filters, @link https://developer.wordpress.org/plugins/
*
* @package WordPress
* @subpackage lavinya_black
*/
// Set up the content width value based on the theme's design and stylesheet.
if ( ! isset( $content_width ) ) {
$content_width = 625;
}
/**
* Lavinya Black setup.
*
* Sets up theme defaults and registers the various WordPress features that
* Lavinya Black supports.
*
* @uses load_theme_textdomain() For translation/localization support.
* @uses add_editor_style() To add a Visual Editor stylesheet.
* @uses add_theme_support() To add support for post thumbnails, automatic feed links,
* custom background, and post formats.
* @uses register_nav_menu() To add support for navigation menus.
* @uses set_post_thumbnail_size() To set a custom post thumbnail size.
*
*/
if ( ! function_exists( 'lavinyablack_setup' ) ) :
function lavinyablack_setup() {
/*
* Makes Lavinya Black available for translation.
*
* Translations can be filed at WordPress.org. See: https://translate.wordpress.org/projects/wp-themes/lavinyablack
* If you're building a theme based on Lavinya Black, use a find and replace
* to change 'lavinyablack' to the name of your theme in all the template files.
*/
load_theme_textdomain( 'lavinyablack', get_template_directory() . '/languages' );
/*
* Let WordPress manage the document title.
* This theme does not use a hard-coded <title> tag in the document head,
* WordPress will provide it for us.
*/
add_theme_support( 'title-tag' );
/*
* Switch default core markup for search form, comment form, and comments
* to output valid HTML5.
*/
add_theme_support(
'html5',
array(
				'comment-form',
'comment-list',
'caption',
'script',
'style',
'navigation-widgets',
'gallery',
)
);
// This theme styles the visual editor with editor-style.css to match the theme style.
add_editor_style();
// Load regular editor styles into the new block-based editor.
add_theme_support( 'editor-styles' );
// Load default block styles.
add_theme_support( 'wp-block-styles' );
// Add support for responsive embeds.
add_theme_support( 'responsive-embeds' );
// Add support for custom color scheme.
add_theme_support(
'editor-color-palette',
array(
array(
'name' => __( 'Blue', 'lavinyablack' ),
'slug' => 'blue',
'color' => '#21759b',
),
array(
'name' => __( 'Dark Gray', 'lavinyablack' ),
'slug' => 'dark-gray',
'color' => '#444',
),
array(
'name' => __( 'Medium Gray', 'lavinyablack' ),
'slug' => 'medium-gray',
'color' => '#9f9f9f',
),
array(
'name' => __( 'Light Gray', 'lavinyablack' ),
'slug' => 'light-gray',
'color' => '#e6e6e6',
),
array(
'name' => __( 'White', 'lavinyablack' ),
'slug' => 'white',
'color' => '#fff',
),
array(
'name' => __( 'Black', 'lavinyablack' ),
'slug' => 'black',
'color' => '#000',
),
)
);
// Adds RSS feed links to <head> for posts and comments.
add_theme_support( 'automatic-feed-links' );
// This theme supports a variety of post formats.
add_theme_support(
'post-formats',
array(
'link',
'aside',
'gallery',
'image',
'quote',
'status',
'video',
'audio',
'chat',
)
);
// This theme uses wp_nav_menu() in one location.
register_nav_menu( 'primary', __( 'Primary Menu', 'lavinyablack' ) );
/*
* This theme supports custom background color and image,
* and here we also set up the default background color.
*/
add_theme_support(
'custom-background',
array(
'default-color' => 'e6e6e6',
)
);
// This theme uses a custom image size for featured images, displayed on "standard" posts.
add_theme_support( 'post-thumbnails' );
set_post_thumbnail_size( 624, 9999 ); // Unlimited height, soft crop.
// Indicate widget sidebars can use selective refresh in the Customizer.
add_theme_support( 'customize-selective-refresh-widgets' );
}
endif;
add_action( 'after_setup_theme', 'lavinyablack_setup' );
/**
* Add support for a custom header image.
*/
require get_template_directory() . '/inc/custom-header.php';
/**
* Return the Google font stylesheet URL if available.
*
* The use of Open Sans by default is localized. For languages that use
* characters not supported by the font, the font can be disabled.
*
*
* @return string Font stylesheet or empty string if disabled.
*/
function lavinyablack_get_font_url() {
$font_url = '';
/*
* translators: If there are characters in your language that are not supported
* by Open Sans, translate this to 'off'. Do not translate into your own language.
*/
if ( 'off' !== _x( 'on', 'Open Sans font: on or off', 'lavinyablack' ) ) {
$subsets = 'latin,latin-ext';
/*
* translators: To add an additional Open Sans character subset specific to your language,
* translate this to 'greek', 'cyrillic' or 'vietnamese'. Do not translate into your own language.
*/
$subset = _x( 'no-subset', 'Open Sans font: add new subset (greek, cyrillic, vietnamese)', 'lavinyablack' );
if ( 'cyrillic' === $subset ) {
$subsets .= ',cyrillic,cyrillic-ext';
} elseif ( 'greek' === $subset ) {
$subsets .= ',greek,greek-ext';
} elseif ( 'vietnamese' === $subset ) {
$subsets .= ',vietnamese';
}
$query_args = array(
'family' => urlencode( 'Open Sans:400italic,700italic,400,700' ),
'subset' => urlencode( $subsets ),
'display' => urlencode( 'fallback' ),
);
$font_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
}
return $font_url;
}
if ( ! function_exists( 'lavinyablack_content_nav' ) ) :
function lavinyablack_content_nav( $nav_id ) {
global $wp_query;
if ( $wp_query->max_num_pages > 1 ) : ?>
<?php the_posts_pagination(
array(
'prev_text' => __( '&larr; Newer posts', 'lavinyablack' ),
'next_text' => __( 'Older posts &rarr;', 'lavinyablack' ))); ?>
<?php endif;
}
endif;
/**
* Enqueue scripts and styles for front end.
*
*/
function lavinyablack_scripts_styles() {
global $wp_styles;
/*
* Adds JavaScript to pages with the comment form to support
* sites with threaded comments (when in use).
*/
if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
wp_enqueue_script( 'comment-reply' );
}
// Adds JavaScript for handling the navigation menu hide-and-show behavior.
wp_enqueue_script( 'lavinyablack-navigation', get_template_directory_uri() . '/js/navigation.js', array( 'jquery' ), '20141205', true );
$font_url = lavinyablack_get_font_url();
if ( ! empty( $font_url ) ) {
wp_enqueue_style( 'lavinyablack-fonts', esc_url_raw( $font_url ), array(), null );
}
// Loads our main stylesheet.
wp_enqueue_style( 'lavinyablack-style', get_stylesheet_uri(), array(), '20190507' );
// Theme block stylesheet.
wp_enqueue_style( 'lavinyablack-block-style', get_template_directory_uri() . '/css/blocks.css', array( 'lavinyablack-style' ), '20190406' );
// Loads the Internet Explorer specific stylesheet.
wp_enqueue_style( 'lavinyablack-ie', get_template_directory_uri() . '/css/ie.css', array( 'lavinyablack-style' ), '20150214' );
$wp_styles->add_data( 'lavinyablack-ie', 'conditional', 'lt IE 9' );
}
add_action( 'wp_enqueue_scripts', 'lavinyablack_scripts_styles' );
/**
* Enqueue styles for the block-based editor.
*
*/
function lavinyablack_block_editor_styles() {
// Block styles.
wp_enqueue_style( 'lavinyablack-block-editor-style', get_template_directory_uri() . '/css/editor-blocks.css', array(), '20190406' );
// Add custom fonts.
wp_enqueue_style( 'lavinyablack-fonts', lavinyablack_get_font_url(), array(), null );
}
add_action( 'enqueue_block_editor_assets', 'lavinyablack_block_editor_styles' );
/**
* Add preconnect for Google Fonts.
*
*
* @param array $urls URLs to print for resource hints.
* @param string $relation_type The relation type the URLs are printed.
* @return array URLs to print for resource hints.
*/
function lavinyablack_resource_hints( $urls, $relation_type ) {
if ( wp_style_is( 'lavinyablack-fonts', 'queue' ) && 'preconnect' === $relation_type ) {
if ( version_compare( $GLOBALS['wp_version'], '4.7-alpha', '>=' ) ) {
$urls[] = array(
'href' => 'https://fonts.gstatic.com',
'crossorigin',
);
} else {
$urls[] = 'https://fonts.gstatic.com';
}
}
return $urls;
}
add_filter( 'wp_resource_hints', 'lavinyablack_resource_hints', 10, 2 );
/**
* Filter TinyMCE CSS path to include Google Fonts.
*
* Adds additional stylesheets to the TinyMCE editor if needed.
*
* @uses lavinyablack_get_font_url() To get the Google Font stylesheet URL.
*
*
* @param string $mce_css CSS path to load in TinyMCE.
* @return string Filtered CSS path.
*/
function lavinyablack_mce_css( $mce_css ) {
$font_url = lavinyablack_get_font_url();
if ( empty( $font_url ) ) {
return $mce_css;
}
if ( ! empty( $mce_css ) ) {
$mce_css .= ',';
}
$mce_css .= esc_url_raw( str_replace( ',', '%2C', $font_url ) );
return $mce_css;
}
add_filter( 'mce_css', 'lavinyablack_mce_css' );
/**
* Filter the page menu arguments.
*
* Makes our wp_nav_menu() fallback -- wp_page_menu() -- show a home link.
*
*/
function lavinyablack_page_menu_args( $args ) {
if ( ! isset( $args['show_home'] ) ) {
$args['show_home'] = true;
}
return $args;
}
add_filter( 'wp_page_menu_args', 'lavinyablack_page_menu_args' );
/**
* Register sidebars.
*
* Registers our main widget area and the front page widget areas.
*/
function lavinyablack_widgets_init() {
register_sidebar(
array(
'name' => __( 'Main Sidebar', 'lavinyablack' ),
'id' => 'sidebar-1',
'description' => __( 'Appears on posts and pages except the optional Front Page template, which has its own widgets', 'lavinyablack' ),
'before_widget' => '<aside id="%1$s" class="widget %2$s">',
'after_widget' => '</aside>',
'before_title' => '<h3 class="widget-title">',
'after_title' => '</h3>',
)
);
register_sidebar(
array(
'name' => __( 'First Front Page Widget Area', 'lavinyablack' ),
'id' => 'sidebar-2',
'description' => __( 'Appears when using the optional Front Page template with a page set as Static Front Page', 'lavinyablack' ),
'before_widget' => '<aside id="%1$s" class="widget %2$s">',
'after_widget' => '</aside>',
'before_title' => '<h3 class="widget-title">',
'after_title' => '</h3>',
)
);
register_sidebar(
array(
'name' => __( 'Second Front Page Widget Area', 'lavinyablack' ),
'id' => 'sidebar-3',
'description' => __( 'Appears when using the optional Front Page template with a page set as Static Front Page', 'lavinyablack' ),
'before_widget' => '<aside id="%1$s" class="widget %2$s">',
'after_widget' => '</aside>',
'before_title' => '<h3 class="widget-title">',
'after_title' => '</h3>',
)
);
}
add_action( 'widgets_init', 'lavinyablack_widgets_init' );


if ( ! function_exists( 'lavinyablack_comment' ) ) :
/**
* Template for comments and pingbacks.
*
* To override this walker in a child theme without modifying the comments template
* simply create your own lavinyablack_comment(), and that function will be used instead.
*
* Used as a callback by wp_list_comments() for displaying the comments.
*
*/
function lavinyablack_comment( $comment, $args, $depth ) {
$GLOBALS['comment'] = $comment;
switch ( $comment->comment_type ) :
case 'pingback':
case 'trackback':
// Display trackbacks differently than normal comments.
?>
<li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">
<p><?php _e( 'Pingback:', 'lavinyablack' ); ?> <?php comment_author_link(); ?> <?php edit_comment_link( __( '(Edit)', 'lavinyablack' ), '<span class="edit-link">', '</span>' ); ?></p>
<?php
break;
default:
// Proceed with normal comments.
global $post;
?>
<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
<article id="comment-<?php comment_ID(); ?>" class="comment">
<header class="comment-meta comment-author vcard">
<?php
echo get_avatar( $comment, 44 );
printf(
'<cite><b class="fn">%1$s</b> %2$s</cite>',
get_comment_author_link(),
// If current post author is also comment author, make it known visually.
( $comment->user_id === $post->post_author ) ? '<span>' . __( 'Post author', 'lavinyablack' ) . '</span>' : ''
);
printf(
'<a href="%1$s"><time datetime="%2$s">%3$s</time></a>',
esc_url( get_comment_link( $comment->comment_ID ) ),
get_comment_time( 'c' ),
/* translators: 1: Date, 2: Time. */
sprintf( __( '%1$s at %2$s', 'lavinyablack' ), get_comment_date(), get_comment_time() )
);
?>
</header><!-- .comment-meta -->
<?php
$commenter = wp_get_current_commenter();
if ( $commenter['comment_author_email'] ) {
$moderation_note = __( 'Your comment is awaiting moderation.', 'lavinyablack' );
} else {
$moderation_note = __( 'Your comment is awaiting moderation. This is a preview; your comment will be visible after it has been approved.', 'lavinyablack' );
}
?>
<?php if ( '0' == $comment->comment_approved ) : ?>
<p class="comment-awaiting-moderation"><?php echo $moderation_note; ?></p>
<?php endif; ?>
<section class="comment-content comment">
<?php comment_text(); ?>
<?php edit_comment_link( __( 'Edit', 'lavinyablack' ), '<p class="edit-link">', '</p>' ); ?>
</section><!-- .comment-content -->
<div class="reply">
<?php
comment_reply_link(
array_merge(
$args,
array(
'reply_text' => __( 'Reply', 'lavinyablack' ),
'after' => ' <span>&darr;</span>',
'depth' => $depth,
'max_depth' => $args['max_depth'],
)
)
);
?>
</div><!-- .reply -->
</article><!-- #comment-## -->
<?php
break;
endswitch; // End comment_type check.
}
endif;
if ( ! function_exists( 'lavinyablack_entry_meta' ) ) :
/**
* Set up post entry meta.
*
* Prints HTML with meta information for current post: categories, tags, permalink, author, and date.
*
* Create your own lavinyablack_entry_meta() to override in a child theme.
*
*/
function lavinyablack_entry_meta() {
/* translators: Used between list items, there is a space after the comma. */
$categories_list = get_the_category_list( __( ', ', 'lavinyablack' ) );
/* translators: Used between list items, there is a space after the comma. */
$tags_list = get_the_tag_list( '', __( ', ', 'lavinyablack' ) );
$date = sprintf(
'<a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s">%4$s</time></a>',
esc_url( get_permalink() ),
esc_attr( get_the_time() ),
esc_attr( get_the_date( 'c' ) ),
esc_html( get_the_date() )
);
$author = sprintf(
'<span class="author vcard"><a class="url fn n" href="%1$s" title="%2$s" rel="author">%3$s</a></span>',
esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
/* translators: %s: Author display name. */
esc_attr( sprintf( __( 'View all posts by %s', 'lavinyablack' ), get_the_author() ) ),
get_the_author()
);
if ( $tags_list && ! is_wp_error( $tags_list ) ) {
/* translators: 1: Category name, 2: Tag name, 3: Date, 4: Author display name. */
$utility_text = __( 'This entry was posted in %1$s and tagged %2$s on %3$s<span class="by-author"> by %4$s</span>.', 'lavinyablack' );
} elseif ( $categories_list ) {
/* translators: 1: Category name, 3: Date, 4: Author display name. */
$utility_text = __( 'This entry was posted in %1$s on %3$s<span class="by-author"> by %4$s</span>.', 'lavinyablack' );
} else {
/* translators: 3: Date, 4: Author display name. */
$utility_text = __( 'This entry was posted on %3$s<span class="by-author"> by %4$s</span>.', 'lavinyablack' );
}
printf(
$utility_text,
$categories_list,
$tags_list,
$date,
$author
);
}
endif;
/**
* Extend the default WordPress body classes.
*
* Extends the default WordPress body class to denote:
* 1. Using a full-width layout, when no active widgets in the sidebar
* or full-width template.
* 2. Front Page template: thumbnail in use and number of sidebars for
* widget areas.
* 3. White or empty background color to change the layout and spacing.
* 4. Custom fonts enabled.
* 5. Single or multiple authors.
*
*
* @param array $classes Existing class values.
* @return array Filtered class values.
*/
function lavinyablack_body_class( $classes ) {
$background_color = get_background_color();
$background_image = get_background_image();
if ( ! is_active_sidebar( 'sidebar-1' ) || is_page_template( 'page-templates/full-width.php' ) ) {
$classes[] = 'full-width';
}
if ( is_page_template( 'page-templates/front-page.php' ) ) {
$classes[] = 'template-front-page';
if ( has_post_thumbnail() ) {
$classes[] = 'has-post-thumbnail';
}
if ( is_active_sidebar( 'sidebar-2' ) && is_active_sidebar( 'sidebar-3' ) ) {
$classes[] = 'two-sidebars';
}
}
if ( empty( $background_image ) ) {
if ( empty( $background_color ) ) {
$classes[] = 'custom-background-empty';
} elseif ( in_array( $background_color, array( 'fff', 'ffffff' ), true ) ) {
$classes[] = 'custom-background-white';
}
}
// Enable custom font class only if the font CSS is queued to load.
if ( wp_style_is( 'lavinyablack-fonts', 'queue' ) ) {
$classes[] = 'custom-font-enabled';
}
if ( ! is_multi_author() ) {
$classes[] = 'single-author';
}
return $classes;
}
add_filter( 'body_class', 'lavinyablack_body_class' );
/**
* Adjust content width in certain contexts.
*
* Adjusts content_width value for full-width and single image attachment
* templates, and when there are no active widgets in the sidebar.
*
*/
function lavinyablack_content_width() {
if ( is_page_template( 'page-templates/full-width.php' ) || is_attachment() || ! is_active_sidebar( 'sidebar-1' ) ) {
global $content_width;
$content_width = 960;
}
}
add_action( 'template_redirect', 'lavinyablack_content_width' );
/**
* Register postMessage support.
*
* Add postMessage support for site title and description for the Customizer.
*
*
* @param WP_Customize_Manager $wp_customize Customizer object.
*/
function lavinyablack_customize_register( $wp_customize ) {
$wp_customize->get_setting( 'blogname' )->transport = 'postMessage';
$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';
$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
if ( isset( $wp_customize->selective_refresh ) ) {
$wp_customize->selective_refresh->add_partial(
'blogname',
array(
'selector' => '.site-title > a',
'container_inclusive' => false,
'render_callback' => 'lavinyablack_customize_partial_blogname',
)
);
$wp_customize->selective_refresh->add_partial(
'blogdescription',
array(
'selector' => '.site-description',
'container_inclusive' => false,
'render_callback' => 'lavinyablack_customize_partial_blogdescription',
)
);
}
}
add_action( 'customize_register', 'lavinyablack_customize_register' );
/**
* Render the site title for the selective refresh partial.
*
*
* @see lavinyablack_customize_register()
*
* @return void
*/
function lavinyablack_customize_partial_blogname() {
bloginfo( 'name' );
}
/**
* Render the site tagline for the selective refresh partial.
*
*
* @see lavinyablack_customize_register()
*
* @return void
*/
function lavinyablack_customize_partial_blogdescription() {
bloginfo( 'description' );
}
/**
* Enqueue JavaScript postMessage handlers for the Customizer.
*
* Binds JS handlers to make the Customizer preview reload changes asynchronously.
*
*/
function lavinyablack_customize_preview_js() {
wp_enqueue_script( 'lavinyablack-customizer', get_template_directory_uri() . '/js/theme-customizer.js', array( 'customize-preview' ), '20141120', true );
}
add_action( 'customize_preview_init', 'lavinyablack_customize_preview_js' );
/**
* Modifies tag cloud widget arguments to display all tags in the same font size
* and use list format for better accessibility.
*
*
* @param array $args Arguments for tag cloud widget.
* @return array The filtered arguments for tag cloud widget.
*/
function lavinyablack_widget_tag_cloud_args( $args ) {
$args['largest'] = 22;
$args['smallest'] = 8;
$args['unit'] = 'pt';
$args['format'] = 'list';
return $args;
}
add_filter( 'widget_tag_cloud_args', 'lavinyablack_widget_tag_cloud_args' );
if ( ! function_exists( 'wp_body_open' ) ) :
/**
* Fire the wp_body_open action.
*
* Added for backward compatibility to support pre-5.2.0 WordPress versions.
*
*/
function wp_body_open() {
/**
* Triggered after the opening <body> tag.
*
*/
do_action( 'wp_body_open' );
}
endif;
